# caaalle

[![image](https://img.shields.io/pypi/v/caaalle.svg)](https://pypi.org/project/caaalle/)
[![Build Status](https://github.com/caalle/caaalle/workflows/Release/badge.svg)](https://github.com/caalle/caaalle/workflows/Release/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/caaalle/badge/?version=latest)](https://caaalle.readthedocs.io/en/latest/?badge=latest)
[![Downloads](https://img.shields.io/pypi/dm/caaalle)](https://img.shields.io/pypi/dm/caaalle)
[![](https://img.shields.io/pypi/pyversions/caaalle.svg)](https://pypi.org/pypi/caaalle/)
[![](https://img.shields.io/pypi/l/caaalle.svg)](https://pypi.org/pypi/caaalle/)
[![semantic-release](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg)](https://github.com/semantic-release/semantic-release)
